==================================
``psyclone.psyir.backend.visitor``
==================================

.. automodule:: psyclone.psyir.backend.visitor

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.visitor


Classes
=======

- :py:class:`PSyIRVisitor`:
  A generic PSyIR visitor. This is designed to be specialised by


.. autoclass:: PSyIRVisitor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: PSyIRVisitor
      :parts: 1


Exceptions
==========

- :py:exc:`VisitorError`:
  Provides a PSyclone-specific error class for errors related to a


.. autoexception:: VisitorError

   .. rubric:: Inheritance
   .. inheritance-diagram:: VisitorError
      :parts: 1
